# Generated by Django 4.2.7 on 2024-01-19 13:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0027_merge_20240118_1324"),
    ]

    operations = [
        migrations.AddField(
            model_name="khojuser",
            name="verified_phone_number",
            field=models.BooleanField(default=False),
        ),
    ]
