(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3111],{91955:function(e,t,s){Promise.resolve().then(s.bind(s,41694))},41694:function(e,t,s){"use strict";s.r(t),s.d(t,{default:function(){return f}});var a=s(57437),n=s(22515),o=s.n(n),i=s(2265),c=s(53789),r=s(14308);s(2446);var l=s(7436),d=s(56937),h=s(5477),u=s(85872),g=s(34124),m=s(6512),p=s(37104);function x(e){let[t,s]=(0,i.useState)(""),[n,r]=(0,i.useState)([]),[l,d]=(0,i.useState)(!1),[u,g]=(0,i.useState)(null),m=(0,i.useRef)(null),p=e.setQueryToProcess,x=e.streamedMessages,f=e.isMobileWidth?"w-full":"w-4/6";return((0,i.useEffect)(()=>{if(n.length>0){let t=n.map(e=>encodeURIComponent(e));e.setImages(t)}},[n,e.setImages]),(0,i.useEffect)(()=>{t&&(d(!0),p(t))},[t,p]),(0,i.useEffect)(()=>{x&&x.length>0&&x[x.length-1].completed?d(!1):s("")},[x]),e.publicConversationSlug||e.conversationId)?(0,a.jsxs)(a.Fragment,{children:[(0,a.jsx)("div",{className:o().chatBodyFull,children:(0,a.jsx)(c.Z,{publicConversationSlug:e.publicConversationSlug,conversationId:e.conversationId||"",setAgent:g,setTitle:e.setTitle,pendingMessage:l?t:"",incomingMessages:e.streamedMessages,customClassName:f})}),(0,a.jsx)("div",{className:"".concat(o().inputBox," p-1 md:px-2 shadow-md bg-background align-middle items-center justify-center dark:bg-neutral-700 dark:border-0 dark:shadow-sm rounded-2xl md:rounded-xl h-fit ").concat(f," mr-auto ml-auto"),children:(0,a.jsx)(h.a,{isLoggedIn:e.isLoggedIn,sendMessage:e=>s(e),sendImage:e=>r(t=>[...t,e]),sendDisabled:l,chatOptionsData:e.chatOptionsData,conversationId:e.conversationId,agentColor:null==u?void 0:u.color,isMobileWidth:e.isMobileWidth,setUploadedFiles:e.setUploadedFiles,setTriggeredAbort:()=>{},ref:m})})]}):(0,a.jsx)("div",{className:o().suggestions,children:"Whoops, nothing to see here!"})}function f(){let[e,t]=(0,i.useState)(null),[s,n]=(0,i.useState)(!0),[c,h]=(0,i.useState)("Khoj AI - Chat"),[f,_]=(0,i.useState)(void 0),[v,j]=(0,i.useState)([]),[S,C]=(0,i.useState)(""),[I,b]=(0,i.useState)(null),[N,y]=(0,i.useState)(void 0),[B,w]=(0,i.useState)([]),{data:O,error:k,isLoading:M}=(0,d.GW)(),E=(0,l.IC)();return((0,i.useEffect)(()=>{fetch("/api/chat/options").then(e=>e.json()).then(e=>{n(!1),e&&t(e)}).catch(e=>{console.error(e)}),(0,l.EK)(),y(window.location.pathname.split("/").pop()||"")},[]),(0,i.useEffect)(()=>{I&&localStorage.setItem("uploadedFiles",JSON.stringify(I))},[I]),(0,i.useEffect)(()=>{if(S&&!f){fetch("/api/chat/share/fork?public_conversation_slug=".concat(N),{method:"POST",headers:{"Content-Type":"application/json"}}).then(e=>e.json()).then(e=>{_(e.conversation_id),localStorage.setItem("message",S),B.length>0&&localStorage.setItem("images",JSON.stringify(B)),window.location.href="/chat?conversationId=".concat(e.conversation_id)}).catch(e=>{console.error(e)});return}},[S,f,N]),s)?(0,a.jsx)(r.Z,{}):N?(0,a.jsxs)(u.Hn,{children:[(0,a.jsx)(g.S,{conversationId:f||""}),(0,a.jsxs)(u.kV,{children:[(0,a.jsxs)("header",{className:"flex h-16 shrink-0 items-center gap-2 border-b px-4",children:[(0,a.jsx)(u.vP,{className:"-ml-1"}),(0,a.jsx)(m.Z,{orientation:"vertical",className:"mr-2 h-4"}),N&&(0,a.jsx)("div",{className:"".concat(o().chatTitleWrapper," text-nowrap text-ellipsis overflow-hidden max-w-screen-md grid items-top font-bold mx-2 md:mr-8 col-auto h-fit"),children:E?(0,a.jsx)("a",{className:"p-0 no-underline",href:"/",children:(0,a.jsx)(p.VO,{className:"h-auto w-16"})}):c&&(0,a.jsx)(a.Fragment,{children:(0,a.jsx)("h2",{className:"text-lg text-ellipsis whitespace-nowrap overflow-x-hidden mr-4",children:c})})})]}),(0,a.jsxs)("div",{className:"".concat(o().main," ").concat(o().chatLayout),children:[(0,a.jsx)("title",{children:c}),(0,a.jsx)("div",{className:o().chatBox,children:(0,a.jsx)("div",{className:o().chatBoxBody,children:(0,a.jsx)(i.Suspense,{fallback:(0,a.jsx)(r.Z,{}),children:(0,a.jsx)(x,{conversationId:f,streamedMessages:v,setQueryToProcess:C,isLoggedIn:!!O,publicConversationSlug:N,chatOptionsData:e,setTitle:h,setUploadedFiles:b,isMobileWidth:E,setImages:w})})})})]})]})]}):(0,a.jsx)("div",{className:o().suggestions,children:"Whoops, nothing to see here!"})}},22515:function(e){e.exports={main:"sharedChat_main__7Nayy",suggestions:"sharedChat_suggestions__V8kr_",inputBox:"sharedChat_inputBox__wRW5A",chatBodyFull:"sharedChat_chatBodyFull__O1MOv",chatBody:"sharedChat_chatBody__OnHDL",chatLayout:"sharedChat_chatLayout__gutlc",chatBox:"sharedChat_chatBox__PmAPg",titleBar:"sharedChat_titleBar__vOHp_",chatBoxBody:"sharedChat_chatBoxBody__ef2Nl",agentIndicator:"sharedChat_agentIndicator__ORCl4"}}},function(e){e.O(0,[9346,8255,1887,3954,9259,8667,182,1010,6293,4124,5477,3789,2971,2117,1744],function(){return e(e.s=91955)}),_N_E=e.O()}]);