# Generated by Django 5.0.7 on 2024-08-16 18:18

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0056_searchmodelconfig_cross_encoder_model_config"),
    ]

    operations = [
        migrations.RenameField(
            model_name="serverchatsettings",
            old_name="default_model",
            new_name="chat_default",
        ),
        migrations.RemoveField(
            model_name="serverchatsettings",
            name="summarizer_model",
        ),
        migrations.AddField(
            model_name="chatmodeloptions",
            name="subscribed_max_prompt_size",
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name="serverchatsettings",
            name="chat_advanced",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="chat_advanced",
                to="database.chatmodeloptions",
            ),
        ),
        migrations.AlterField(
            model_name="serverchatsettings",
            name="chat_default",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="chat_default",
                to="database.chatmodeloptions",
            ),
        ),
    ]
