# Generated by Django 4.2.11 on 2024-06-28 06:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0049_datastore"),
    ]

    operations = [
        migrations.AlterField(
            model_name="processlock",
            name="name",
            field=models.CharField(
                choices=[
                    ("index_content", "Index Content"),
                    ("scheduled_job", "Scheduled Job"),
                    ("schedule_leader", "Schedule Leader"),
                ],
                max_length=200,
                unique=True,
            ),
        ),
    ]
